@@ -25,7 +25,7 @@ class ListService(command.Lister):
     log = logging.getLogger(__name__ + ".ListService")
 
     def get_parser(self, prog_name):
-        parser = super(ListService, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         return parser
 
     def take_action(self, parsed_args):
