@@ -14,12 +14,12 @@
 """Orchestration v1 Stack Snapshot implementations."""
 
 import logging
+import sys
 
 from osc_lib.command import command
 from osc_lib import exceptions as exc
 from osc_lib.i18n import _
 from osc_lib import utils
-import six
 
 from heatclient.common import format_utils
 from heatclient import exc as heat_exc
@@ -31,7 +31,7 @@ class ListSnapshot(command.Lister):
     log = logging.getLogger(__name__ + ".ListSnapshot")
 
     def get_parser(self, prog_name):
-        parser = super(ListSnapshot, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'stack',
             metavar='<stack>',
@@ -40,7 +40,7 @@ class ListSnapshot(command.Lister):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)' % parsed_args)
+        self.log.debug('take_action(%s)', parsed_args)
         heat_client = self.app.client_manager.orchestration
         return self._list_snapshot(heat_client, parsed_args)
 
@@ -52,7 +52,14 @@ class ListSnapshot(command.Lister):
             raise exc.CommandError(_('Stack not found: %s') %
                                    parsed_args.stack)
 
-        columns = ['id', 'name', 'status', 'status_reason', 'creation_time']
+        columns = [
+            'id',
+            'name',
+            'action',
+            'status',
+            'status_reason',
+            'creation_time'
+        ]
         return (
             columns,
             (utils.get_dict_properties(s, columns)
@@ -66,7 +73,7 @@ class ShowSnapshot(format_utils.YamlFormat):
     log = logging.getLogger(__name__ + ".ShowSnapshot")
 
     def get_parser(self, prog_name):
-        parser = super(ShowSnapshot, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'stack',
             metavar='<stack>',
@@ -80,7 +87,7 @@ class ShowSnapshot(format_utils.YamlFormat):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)' % parsed_args)
+        self.log.debug('take_action(%s)', parsed_args)
         heat_client = self.app.client_manager.orchestration
         return self._show_snapshot(heat_client, parsed_args.stack,
                                    parsed_args.snapshot)
@@ -94,8 +101,8 @@ class ShowSnapshot(format_utils.YamlFormat):
                                    % {'snapshot_id': snapshot_id,
                                       'stack_id': stack_id})
 
-        rows = list(six.itervalues(data))
-        columns = list(six.iterkeys(data))
+        rows = list(data.values())
+        columns = list(data.keys())
         return columns, rows
 
 
@@ -105,7 +112,7 @@ class RestoreSnapshot(command.Command):
     log = logging.getLogger(__name__ + ".RestoreSnapshot")
 
     def get_parser(self, prog_name):
-        parser = super(RestoreSnapshot, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'stack',
             metavar='<stack>',
@@ -119,7 +126,7 @@ class RestoreSnapshot(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)' % parsed_args)
+        self.log.debug('take_action(%s)', parsed_args)
         heat_client = self.app.client_manager.orchestration
         return self._restore_snapshot(heat_client, parsed_args)
 
@@ -141,7 +148,7 @@ class CreateSnapshot(command.ShowOne):
     log = logging.getLogger(__name__ + ".CreateSnapshot")
 
     def get_parser(self, prog_name):
-        parser = super(CreateSnapshot, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'stack',
             metavar='<stack>',
@@ -155,7 +162,7 @@ class CreateSnapshot(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)' % parsed_args)
+        self.log.debug('take_action(%s)', parsed_args)
         heat_client = self.app.client_manager.orchestration
 
         try:
@@ -168,6 +175,7 @@ class CreateSnapshot(command.ShowOne):
         columns = [
             'ID',
             'name',
+            'action',
             'status',
             'status_reason',
             'data',
@@ -181,7 +189,7 @@ class DeleteSnapshot(command.Command):
     log = logging.getLogger(__name__ + ".DeleteSnapshot")
 
     def get_parser(self, prog_name):
-        parser = super(DeleteSnapshot, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             'stack',
             metavar='<stack>',
@@ -192,11 +200,34 @@ class DeleteSnapshot(command.Command):
             metavar='<snapshot>',
             help=_('ID of stack snapshot')
         )
+        parser.add_argument(
+            '-y', '--yes',
+            action='store_true',
+            help=_('Skip yes/no prompt (assume yes)')
+        )
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)' % parsed_args)
+        self.log.debug('take_action(%s)', parsed_args)
         heat_client = self.app.client_manager.orchestration
+        msg = ('User did not confirm snapshot delete '
+               '%sso taking no action.')
+        try:
+            if not parsed_args.yes and sys.stdin.isatty():
+                sys.stdout.write(
+                    _('Are you sure you want to delete the snapshot of this '
+                      'stack [Y/N]?'))
+                prompt_response = sys.stdin.readline().lower()
+                if not prompt_response.startswith('y'):
+                    self.log.info(msg, '')
+                    return
+        except KeyboardInterrupt:  # ctrl-c
+            self.log.info(msg, '(ctrl-c) ')
+            return
+        except EOFError:  # ctrl-d
+            self.log.info(msg, '(ctrl-d) ')
+            return
+
         try:
             heat_client.stacks.snapshot_delete(parsed_args.stack,
                                                parsed_args.snapshot)
