@@ -10,7 +10,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 import testtools
 
 from heatclient.common import event_utils
@@ -18,6 +19,15 @@ from heatclient.v1 import events as hc_ev
 from heatclient.v1 import resources as hc_res
 
 
+class FakeWebSocket:
+
+    def __init__(self, events):
+        self.events = events
+
+    def recv(self):
+        return self.events.pop(0)
+
+
 class ShellTestEventUtils(testtools.TestCase):
     @staticmethod
     def _mock_resource(resource_id, nested_id=None):
@@ -38,7 +48,9 @@ class ShellTestEventUtils(testtools.TestCase):
     @staticmethod
     def _mock_event(event_id, resource_id,
                     resource_status='CREATE_COMPLETE'):
-        ev_info = {"links": [{"href": "http://heat/foo", "rel": "self"}],
+        ev_info = {"links": [
+                   {"href": "http://heat/foo", "rel": "self"},
+                   {"href": "http://heat/stacks/astack", "rel": "stack"}],
                    "logical_resource_id": resource_id,
                    "physical_resource_id": resource_id,
                    "resource_name": resource_id,
@@ -48,6 +60,24 @@ class ShellTestEventUtils(testtools.TestCase):
                    "id": event_id}
         return hc_ev.Event(manager=None, info=ev_info)
 
+    @staticmethod
+    def _mock_stack_event(event_id, stack_name,
+                          stack_status='CREATE_COMPLETE'):
+        stack_id = 'abcdef'
+        ev_info = {"links": [
+                        {"href": "http://heat/foo", "rel": "self"},
+                        {"href": "http://heat/stacks/{}/{}".format(stack_name,
+                                                                   stack_id),
+                         "rel": "stack"}],
+                   "logical_resource_id": stack_name,
+                   "physical_resource_id": stack_id,
+                   "resource_name": stack_name,
+                   "resource_status": stack_status,
+                   "resource_status_reason": "state changed",
+                   "event_time": "2014-12-05T14:14:30Z",
+                   "id": event_id}
+        return hc_ev.Event(manager=None, info=ev_info)
+
     def test_get_nested_ids(self):
         def list_stub(stack_id):
             return [self._mock_resource('aresource', 'foo3/3id')]
@@ -134,7 +164,7 @@ class ShellTestEventUtils(testtools.TestCase):
     @mock.patch('heatclient.common.event_utils.get_events')
     def test_poll_for_events(self, ge):
         ge.side_effect = [[
-            self._mock_event('1', 'astack', 'CREATE_IN_PROGRESS'),
+            self._mock_stack_event('1', 'astack', 'CREATE_IN_PROGRESS'),
             self._mock_event('2', 'res_child1', 'CREATE_IN_PROGRESS'),
             self._mock_event('3', 'res_child2', 'CREATE_IN_PROGRESS'),
             self._mock_event('4', 'res_child3', 'CREATE_IN_PROGRESS')
@@ -142,7 +172,7 @@ class ShellTestEventUtils(testtools.TestCase):
             self._mock_event('5', 'res_child1', 'CREATE_COMPLETE'),
             self._mock_event('6', 'res_child2', 'CREATE_COMPLETE'),
             self._mock_event('7', 'res_child3', 'CREATE_COMPLETE'),
-            self._mock_event('8', 'astack', 'CREATE_COMPLETE')
+            self._mock_stack_event('8', 'astack', 'CREATE_COMPLETE')
         ]]
 
         stack_status, msg = event_utils.poll_for_events(
@@ -158,13 +188,42 @@ class ShellTestEventUtils(testtools.TestCase):
             })
         ])
 
+    @mock.patch('heatclient.common.event_utils.get_events')
+    def test_poll_for_events_same_name(self, ge):
+        ge.side_effect = [[
+            self._mock_stack_event('1', 'mything', 'CREATE_IN_PROGRESS'),
+            self._mock_event('2', 'res_child1', 'CREATE_IN_PROGRESS'),
+            self._mock_event('3', 'mything', 'CREATE_IN_PROGRESS'),
+        ], [
+            self._mock_event('4', 'mything', 'CREATE_COMPLETE'),
+        ], [
+            self._mock_event('5', 'res_child1', 'CREATE_COMPLETE'),
+            self._mock_stack_event('6', 'mything', 'CREATE_COMPLETE'),
+        ]]
+
+        stack_status, msg = event_utils.poll_for_events(
+            None, 'mything', action='CREATE', poll_period=0)
+        self.assertEqual('CREATE_COMPLETE', stack_status)
+        self.assertEqual('\n Stack mything CREATE_COMPLETE \n', msg)
+        ge.assert_has_calls([
+            mock.call(None, stack_id='mything', nested_depth=0, event_args={
+                'sort_dir': 'asc', 'marker': None
+            }),
+            mock.call(None, stack_id='mything', nested_depth=0, event_args={
+                'sort_dir': 'asc', 'marker': '3'
+            }),
+            mock.call(None, stack_id='mything', nested_depth=0, event_args={
+                'sort_dir': 'asc', 'marker': '4'
+            })
+        ])
+
     @mock.patch('heatclient.common.event_utils.get_events')
     def test_poll_for_events_with_marker(self, ge):
         ge.side_effect = [[
             self._mock_event('5', 'res_child1', 'CREATE_COMPLETE'),
             self._mock_event('6', 'res_child2', 'CREATE_COMPLETE'),
             self._mock_event('7', 'res_child3', 'CREATE_COMPLETE'),
-            self._mock_event('8', 'astack', 'CREATE_COMPLETE')
+            self._mock_stack_event('8', 'astack', 'CREATE_COMPLETE')
         ]]
 
         stack_status, msg = event_utils.poll_for_events(
@@ -181,9 +240,9 @@ class ShellTestEventUtils(testtools.TestCase):
     @mock.patch('heatclient.common.event_utils.get_events')
     def test_poll_for_events_in_progress_resource(self, ge):
         ge.side_effect = [[
-            self._mock_event('1', 'astack', 'CREATE_IN_PROGRESS'),
+            self._mock_stack_event('1', 'astack', 'CREATE_IN_PROGRESS'),
             self._mock_event('2', 'res_child1', 'CREATE_IN_PROGRESS'),
-            self._mock_event('3', 'astack', 'CREATE_COMPLETE')
+            self._mock_stack_event('3', 'astack', 'CREATE_COMPLETE')
         ]]
 
         stack_status, msg = event_utils.poll_for_events(
@@ -194,7 +253,7 @@ class ShellTestEventUtils(testtools.TestCase):
     @mock.patch('heatclient.common.event_utils.get_events')
     def test_poll_for_events_failed(self, ge):
         ge.side_effect = [[
-            self._mock_event('1', 'astack', 'CREATE_IN_PROGRESS'),
+            self._mock_stack_event('1', 'astack', 'CREATE_IN_PROGRESS'),
             self._mock_event('2', 'res_child1', 'CREATE_IN_PROGRESS'),
             self._mock_event('3', 'res_child2', 'CREATE_IN_PROGRESS'),
             self._mock_event('4', 'res_child3', 'CREATE_IN_PROGRESS')
@@ -202,7 +261,7 @@ class ShellTestEventUtils(testtools.TestCase):
             self._mock_event('5', 'res_child1', 'CREATE_COMPLETE'),
             self._mock_event('6', 'res_child2', 'CREATE_FAILED'),
             self._mock_event('7', 'res_child3', 'CREATE_COMPLETE'),
-            self._mock_event('8', 'astack', 'CREATE_FAILED')
+            self._mock_stack_event('8', 'astack', 'CREATE_FAILED')
         ]]
 
         stack_status, msg = event_utils.poll_for_events(
@@ -213,7 +272,7 @@ class ShellTestEventUtils(testtools.TestCase):
     @mock.patch('heatclient.common.event_utils.get_events')
     def test_poll_for_events_no_action(self, ge):
         ge.side_effect = [[
-            self._mock_event('1', 'astack', 'CREATE_IN_PROGRESS'),
+            self._mock_stack_event('1', 'astack', 'CREATE_IN_PROGRESS'),
             self._mock_event('2', 'res_child1', 'CREATE_IN_PROGRESS'),
             self._mock_event('3', 'res_child2', 'CREATE_IN_PROGRESS'),
             self._mock_event('4', 'res_child3', 'CREATE_IN_PROGRESS')
@@ -221,7 +280,7 @@ class ShellTestEventUtils(testtools.TestCase):
             self._mock_event('5', 'res_child1', 'CREATE_COMPLETE'),
             self._mock_event('6', 'res_child2', 'CREATE_FAILED'),
             self._mock_event('7', 'res_child3', 'CREATE_COMPLETE'),
-            self._mock_event('8', 'astack', 'FOO_FAILED')
+            self._mock_stack_event('8', 'astack', 'FOO_FAILED')
         ]]
 
         stack_status, msg = event_utils.poll_for_events(
@@ -235,7 +294,7 @@ class ShellTestEventUtils(testtools.TestCase):
         mock_client.stacks.get.return_value.stack_status = 'CREATE_FAILED'
 
         ge.side_effect = [[
-            self._mock_event('1', 'astack', 'CREATE_IN_PROGRESS'),
+            self._mock_stack_event('1', 'astack', 'CREATE_IN_PROGRESS'),
             self._mock_event('2', 'res_child1', 'CREATE_IN_PROGRESS'),
             self._mock_event('3', 'res_child2', 'CREATE_IN_PROGRESS'),
             self._mock_event('4', 'res_child3', 'CREATE_IN_PROGRESS')
@@ -245,3 +304,36 @@ class ShellTestEventUtils(testtools.TestCase):
             mock_client, 'astack', action='CREATE', poll_period=0)
         self.assertEqual('CREATE_FAILED', stack_status)
         self.assertEqual('\n Stack astack CREATE_FAILED \n', msg)
+
+    def test_wait_for_events(self):
+        ws = FakeWebSocket([
+            {'body': {
+                'timestamp': '2014-01-06T16:14:26Z',
+                'payload': {'resource_action': 'CREATE',
+                            'resource_status': 'COMPLETE',
+                            'resource_name': 'mystack',
+                            'physical_resource_id': 'stackid1',
+                            'stack_id': 'stackid1'}}}])
+        stack_status, msg = event_utils.wait_for_events(ws, 'mystack')
+        self.assertEqual('CREATE_COMPLETE', stack_status)
+        self.assertEqual('\n Stack mystack CREATE_COMPLETE \n', msg)
+
+    def test_wait_for_events_failed(self):
+        ws = FakeWebSocket([
+            {'body': {
+                'timestamp': '2014-01-06T16:14:23Z',
+                'payload': {'resource_action': 'CREATE',
+                            'resource_status': 'IN_PROGRESS',
+                            'resource_name': 'mystack',
+                            'physical_resource_id': 'stackid1',
+                            'stack_id': 'stackid1'}}},
+            {'body': {
+                'timestamp': '2014-01-06T16:14:26Z',
+                'payload': {'resource_action': 'CREATE',
+                            'resource_status': 'FAILED',
+                            'resource_name': 'mystack',
+                            'physical_resource_id': 'stackid1',
+                            'stack_id': 'stackid1'}}}])
+        stack_status, msg = event_utils.wait_for_events(ws, 'mystack')
+        self.assertEqual('CREATE_FAILED', stack_status)
+        self.assertEqual('\n Stack mystack CREATE_FAILED \n', msg)
