@@ -363,7 +363,7 @@ def do_stack_abandon(hc, args):
             try:
                 with open(args.output_file, "w") as f:
                     f.write(result)
-            except IOError as err:
+            except OSError as err:
                 print(result)
                 raise exc.CommandError(str(err))
         else:
@@ -449,12 +449,6 @@ def do_stack_show(hc, args):
 @utils.arg('-t', '--timeout', metavar='<TIMEOUT>',
            type=int,
            help=_('Stack update timeout in minutes.'))
-@utils.arg('-r', '--enable-rollback', default=False, action="store_true",
-           help=_('DEPRECATED! Use %(arg)s argument instead. '
-                  'Enable rollback on stack update failure. '
-                  'NOTE: default behavior is now to use the rollback value '
-                  'of existing stack.')
-           % {'arg': '--rollback'})
 @utils.arg('--rollback', default=None, metavar='<VALUE>',
            help=_('Set rollback on update failure. '
                   'Values %(true)s  set rollback to enabled. '
@@ -544,11 +538,6 @@ def do_stack_update(hc, args):
             raise exc.CommandError(str(ex))
         else:
             fields['disable_rollback'] = not rollback
-    # TODO(pshchelo): remove the following 'else' clause after deprecation
-    # period of --enable-rollback switch and assign -r shortcut to --rollback
-    else:
-        if args.enable_rollback:
-            fields['disable_rollback'] = False
 
     if args.dry_run is True:
         if args.show_nested:
@@ -1695,10 +1684,13 @@ def do_snapshot_list(hc, args):
     except exc.HTTPNotFound:
         raise exc.CommandError(_('Stack not found: %s') % args.id)
     else:
-        fields = ['id', 'name', 'status', 'status_reason', 'creation_time']
+        fields = [
+            'id', 'name', 'action', 'status', 'status_reason', 'creation_time'
+        ]
         formatters = {
             'id': lambda x: x['id'],
             'name': lambda x: x['name'],
+            'action': lambda x: x['action'],
             'status': lambda x: x['status'],
             'status_reason': lambda x: x['status_reason'],
             'creation_time': lambda x: x['creation_time'],
